@@ -4,8 +4,10 @@
 The same as `ExpMethodHigham2005` but follows `Base.exp` closer.
 """
 struct ExpMethodHigham2005Base end
-function alloc_mem(A::StridedMatrix{T},
-        method::ExpMethodHigham2005Base) where {T <: LinearAlgebra.BlasFloat}
+function alloc_mem(
+        A::StridedMatrix{T},
+        method::ExpMethodHigham2005Base
+    ) where {T <: LinearAlgebra.BlasFloat}
     n = LinearAlgebra.checksquare(A)
     A2 = Matrix{T}(undef, n, n)
     P = Matrix{T}(undef, n, n)
@@ -20,8 +22,10 @@ end
 ##
 ## Non-allocating version of `LinearAlgebra.exp!`. Modifies `A` to
 ## become (approximately) `exp(A)`.
-function exponential!(A::StridedMatrix{T}, method::ExpMethodHigham2005Base,
-        cache = alloc_mem(A, method)) where {T <: LinearAlgebra.BlasFloat}
+function exponential!(
+        A::StridedMatrix{T}, method::ExpMethodHigham2005Base,
+        cache = alloc_mem(A, method)
+    ) where {T <: LinearAlgebra.BlasFloat}
     X = A
     n = LinearAlgebra.checksquare(A)
     # if ishermitian(A)
@@ -44,15 +48,21 @@ function exponential!(A::StridedMatrix{T}, method::ExpMethodHigham2005Base,
     ## For sufficiently small nA, use lower order Padé-Approximations
     if (nA <= 2.1)
         if nA > 0.95
-            C = T[17643225600.0, 8821612800.0, 2075673600.0, 302702400.0,
-            30270240.0, 2162160.0, 110880.0, 3960.0,
-            90.0, 1.0]
+            C = T[
+                17643225600.0, 8821612800.0, 2075673600.0, 302702400.0,
+                30270240.0, 2162160.0, 110880.0, 3960.0,
+                90.0, 1.0,
+            ]
         elseif nA > 0.25
-            C = T[17297280.0, 8648640.0, 1995840.0, 277200.0,
-            25200.0, 1512.0, 56.0, 1.0]
+            C = T[
+                17297280.0, 8648640.0, 1995840.0, 277200.0,
+                25200.0, 1512.0, 56.0, 1.0,
+            ]
         elseif nA > 0.015
-            C = T[30240.0, 15120.0, 3360.0,
-            420.0, 30.0, 1.0]
+            C = T[
+                30240.0, 15120.0, 3360.0,
+                420.0, 30.0, 1.0,
+            ]
         else
             C = T[120.0, 60.0, 12.0, 1.0]
         end
@@ -77,11 +87,13 @@ function exponential!(A::StridedMatrix{T}, method::ExpMethodHigham2005Base,
             si = ceil(Int, s)
             A ./= convert(T, 2^si)
         end
-        C = T[64764752532480000.0, 32382376266240000.0, 7771770303897600.0,
-        1187353796428800.0, 129060195264000.0, 10559470521600.0,
-        670442572800.0, 33522128640.0, 1323241920.0,
-        40840800.0, 960960.0, 16380.0,
-        182.0, 1.0]
+        C = T[
+            64764752532480000.0, 32382376266240000.0, 7771770303897600.0,
+            1187353796428800.0, 129060195264000.0, 10559470521600.0,
+            670442572800.0, 33522128640.0, 1323241920.0,
+            40840800.0, 960960.0, 16380.0,
+            182.0, 1.0,
+        ]
         mul!(A2, A, A)
         @. U = C[2] * P
         @. V = C[1] * P
