@@ -1,4 +1,3 @@
-
 """
     ExpMethodHigham2005(A::AbstractMatrix);
     ExpMethodHigham2005(b::Bool=true);
@@ -40,10 +39,12 @@ const RHO_V = (0.015, 0.25, 0.95, 2.1, 5.4, 10.8, 21.6, 43.2, 86.4, 172.8, 345.6
 # From LinearAlgebra
 const LIBLAPACK = BLAS.libblastrampoline
 using LinearAlgebra: BlasInt, checksquare
-for (gebal, gebak, elty, relty) in ((:dgebal_, :dgebak_, :Float64, :Float64),
-    (:sgebal_, :sgebak_, :Float32, :Float32),
-    (:zgebal_, :zgebak_, :ComplexF64, :Float64),
-    (:cgebal_, :cgebak_, :ComplexF32, :Float32))
+for (gebal, gebak, elty, relty) in (
+        (:dgebal_, :dgebak_, :Float64, :Float64),
+        (:sgebal_, :sgebak_, :Float32, :Float32),
+        (:zgebal_, :zgebak_, :ComplexF64, :Float64),
+        (:cgebal_, :cgebak_, :ComplexF32, :Float32),
+    )
     @eval begin
         #     SUBROUTINE DGEBAL( JOB, N, A, LDA, ILO, IHI, SCALE, INFO )
         #*     .. Scalar Arguments ..
@@ -58,12 +59,16 @@ for (gebal, gebak, elty, relty) in ((:dgebal_, :dgebak_, :Float64, :Float64),
             ihi = Ref{BlasInt}()
             ilo = Ref{BlasInt}()
             info = Ref{BlasInt}()
-            ccall((BLAS.@blasfunc($gebal), LIBLAPACK), Cvoid,
-                (Ref{UInt8}, Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt},
-                    Ptr{BlasInt}, Ptr{BlasInt}, Ptr{$relty}, Ptr{BlasInt}, Clong),
-                job, n, A, max(1, stride(A, 2)), ilo, ihi, scale, info, 1)
+            ccall(
+                (BLAS.@blasfunc($gebal), LIBLAPACK), Cvoid,
+                (
+                    Ref{UInt8}, Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt},
+                    Ptr{BlasInt}, Ptr{BlasInt}, Ptr{$relty}, Ptr{BlasInt}, Clong,
+                ),
+                job, n, A, max(1, stride(A, 2)), ilo, ihi, scale, info, 1
+            )
             LAPACK.chklapackerror(info[])
-            ilo[], ihi[], scale
+            return ilo[], ihi[], scale
         end
     end
 end
@@ -71,7 +76,7 @@ end
 # Inplace add of a UniformScaling object (support julia 1.6.2)
 @inline function inplace_add!(A, B::UniformScaling) # Called from generated code
     s = B.λ
-    if A isa GPUArraysCore.AbstractGPUArray
+    return if A isa GPUArraysCore.AbstractGPUArray
         A .= A + s * I
     else
         @inbounds for i in diagind(A)
@@ -95,11 +100,11 @@ function exponential!(A, method::ExpMethodHigham2005, _cache = alloc_mem(A, meth
     end
 
     # Make the call to the appropriate exp_gen! function
-    X = Base.Cartesian.@nif 13 d->begin
+    X = Base.Cartesian.@nif 13 d -> begin
         nA < RHO_V[d]
-    end d->begin # if condition
+    end d -> begin # if condition
         exp_gen!(cache, A, Val(d))
-    end d->begin # fallback (d == 13)
+    end d -> begin # fallback (d == 13)
         exp_gen!(cache, A, Val(d))
     end
 
