@@ -2,8 +2,10 @@ using ExponentialUtilities, Aqua
 @testset "Aqua" begin
     Aqua.find_persistent_tasks_deps(ExponentialUtilities)
     Aqua.test_ambiguities(ExponentialUtilities, recursive = false)
-    Aqua.test_deps_compat(ExponentialUtilities,
-        ignore = [:libblastrampoline_jll])
+    Aqua.test_deps_compat(
+        ExponentialUtilities,
+        ignore = [:libblastrampoline_jll]
+    )
     Aqua.test_piracies(ExponentialUtilities)
     Aqua.test_project_extras(ExponentialUtilities)
     Aqua.test_stale_deps(ExponentialUtilities)
