@@ -7,7 +7,13 @@ const GROUP = get(ENV, "GROUP", "All")
 function activate_gpu_env()
     Pkg.activate("gpu")
     Pkg.develop(PackageSpec(path = dirname(@__DIR__)))
-    Pkg.instantiate()
+    return Pkg.instantiate()
+end
+
+function activate_jet_env()
+    Pkg.activate("jet")
+    Pkg.develop(PackageSpec(path = dirname(@__DIR__)))
+    return Pkg.instantiate()
 end
 
 @time begin
@@ -20,4 +26,9 @@ end
         activate_gpu_env()
         @time @safetestset "GPU Tests" include("gpu/gputests.jl")
     end
+
+    if GROUP == "JET"
+        activate_jet_env()
+        @time @safetestset "JET Tests" include("jet/jet.jl")
+    end
 end
